@@ -32,6 +32,8 @@ def test_class_sigs():
 
     d = merge_with(identity, toolz_dict, cytoolz_dict)
     for key, (toolz_func, cytoolz_func) in d.items():
+        if key in ['excepts', 'juxt']:
+            continue
         try:
             # function
             toolz_spec = inspect.getargspec(toolz_func)
