@@ -1,4 +1,5 @@
 from cytoolz import *
+import cytoolz
 import pickle
 
 
@@ -28,3 +29,14 @@ def test_complement():
     g = pickle.loads(pickle.dumps(f))
     assert f(True) == g(True)
     assert f(False) == g(False)
+
+
+def test_instanceproperty():
+    p = cytoolz.functoolz.InstanceProperty(bool)
+    assert p.__get__(None) is None
+    assert p.__get__(0) is False
+    assert p.__get__(1) is True
+    p2 = pickle.loads(pickle.dumps(p))
+    assert p2.__get__(None) is None
+    assert p2.__get__(0) is False
+    assert p2.__get__(1) is True
